@@ -18,16 +18,16 @@ The #typeapi.of() function introspects the type hint passed as an argument and c
 using the dataclasses defined in #typeapi.model.
 """
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 from .model import Hint, Type, Union, Annotated, ForwardRef, Any, ClassVar, Final, NoReturn, TypeGuard, Literal, \
     NewType, Unknown, eval_types, infuse_type_parameters
 from .parser import parse_type_hint as of
-from .utils import get_annotations, get_type_hints, type_repr
+from .utils import get_annotations, get_type_hints, scoped, type_repr
 
 __all__ = [
   'Hint', 'Type', 'Union', 'Annotated', 'ForwardRef', 'Any', 'ClassVar', 'Final', 'NoReturn', 'TypeGuard', 'Literal',
   'NewType', 'Unknown', 'eval_types', 'infuse_type_parameters',
   'of',
-  'get_annotations', 'get_type_hints', 'type_repr',
+  'get_annotations', 'get_type_hints', 'scoped', 'type_repr',
 ]
